"use client"

import { useState, useEffect } from "react"
import { useRouter } from "next/navigation"
import { Button } from "@/components/ui/button"
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card"
import { Badge } from "@/components/ui/badge"
import { Input } from "@/components/ui/input"
import { Avatar, AvatarFallback, AvatarImage } from "@/components/ui/avatar"
import {
  MessageSquare,
  Send,
  Search,
  ArrowLeft,
  CheckCircle,
  Paperclip,
  MoreVertical,
  Star,
  PenTool,
} from "lucide-react"
import { getAuthenticatedUser, hasRole } from "@/lib/auth"

// Mock message data
const mockConversations = [
  {
    id: "conv-1",
    orderId: "ORD-004",
    orderTitle: "Historical Analysis of World War II",
    client: {
      name: "Emma Wilson",
      email: "emma.wilson@email.com",
      avatar: "/placeholder.svg?height=40&width=40",
      rating: 4.3,
    },
    lastMessage: "Thank you for the update! The progress looks great so far.",
    lastMessageTime: "2024-01-16 14:30",
    unreadCount: 2,
    status: "active",
    messages: [
      {
        id: "msg-1",
        sender: "client",
        content: "Hi! I wanted to discuss some specific requirements for the Pacific Theater section.",
        timestamp: "2024-01-16 10:00",
        read: true,
      },
      {
        id: "msg-2",
        sender: "writer",
        content:
          "Hello Emma! I'd be happy to discuss the Pacific Theater requirements. What specific aspects would you like me to focus on?",
        timestamp: "2024-01-16 10:15",
        read: true,
      },
      {
        id: "msg-3",
        sender: "client",
        content:
          "I'd like more emphasis on the Battle of Midway and its strategic implications. Also, please include primary sources if possible.",
        timestamp: "2024-01-16 11:00",
        read: true,
      },
      {
        id: "msg-4",
        sender: "writer",
        content:
          "Perfect! I have access to several primary sources including naval records and personal accounts. I'll make sure to highlight the strategic turning point that Midway represented.",
        timestamp: "2024-01-16 11:30",
        read: true,
      },
      {
        id: "msg-5",
        sender: "client",
        content: "Thank you for the update! The progress looks great so far.",
        timestamp: "2024-01-16 14:30",
        read: false,
      },
    ],
  },
  {
    id: "conv-2",
    orderId: "ORD-005",
    orderTitle: "Marketing Campaign Proposal",
    client: {
      name: "Robert Brown",
      email: "robert.brown@email.com",
      avatar: "/placeholder.svg?height=40&width=40",
      rating: 4.6,
    },
    lastMessage: "I've reviewed the revision. Could you add more detail to the social media strategy?",
    lastMessageTime: "2024-01-15 16:45",
    unreadCount: 1,
    status: "revision",
    messages: [
      {
        id: "msg-6",
        sender: "client",
        content: "I've reviewed the revision. Could you add more detail to the social media strategy?",
        timestamp: "2024-01-15 16:45",
        read: false,
      },
    ],
  },
  {
    id: "conv-3",
    orderId: "ORD-006",
    orderTitle: "Psychology Research Proposal",
    client: {
      name: "Sarah Davis",
      email: "sarah.davis@email.com",
      avatar: "/placeholder.svg?height=40&width=40",
      rating: 5.0,
    },
    lastMessage: "Excellent work! Very thorough and well-researched. Thank you!",
    lastMessageTime: "2024-01-09 18:20",
    unreadCount: 0,
    status: "completed",
    messages: [
      {
        id: "msg-7",
        sender: "client",
        content: "Excellent work! Very thorough and well-researched. Thank you!",
        timestamp: "2024-01-09 18:20",
        read: true,
      },
    ],
  },
]

export default function WriterMessagesPage() {
  const router = useRouter()
  const [user, setUser] = useState<any>(null)
  const [conversations, setConversations] = useState(mockConversations)
  const [selectedConversation, setSelectedConversation] = useState<any>(null)
  const [newMessage, setNewMessage] = useState("")
  const [searchQuery, setSearchQuery] = useState("")
  const [isLoading, setIsLoading] = useState(true)

  useEffect(() => {
    const authenticatedUser = getAuthenticatedUser()

    if (!authenticatedUser || !hasRole("writer")) {
      router.push("/auth/login")
      return
    }

    setUser(authenticatedUser)
    setIsLoading(false)

    // Auto-select first conversation if available
    if (conversations.length > 0) {
      setSelectedConversation(conversations[0])
    }
  }, [router])

  const handleSendMessage = () => {
    if (!newMessage.trim() || !selectedConversation) return

    const message = {
      id: `msg-${Date.now()}`,
      sender: "writer",
      content: newMessage,
      timestamp: new Date().toISOString().slice(0, 16).replace("T", " "),
      read: true,
    }

    // Update the conversation
    const updatedConversation = {
      ...selectedConversation,
      messages: [...selectedConversation.messages, message],
      lastMessage: newMessage,
      lastMessageTime: message.timestamp,
    }

    // Update conversations list
    setConversations(conversations.map((conv) => (conv.id === selectedConversation.id ? updatedConversation : conv)))

    // Update selected conversation
    setSelectedConversation(updatedConversation)
    setNewMessage("")
  }

  const markAsRead = (conversationId: string) => {
    setConversations(
      conversations.map((conv) =>
        conv.id === conversationId
          ? {
              ...conv,
              unreadCount: 0,
              messages: conv.messages.map((msg) => ({ ...msg, read: true })),
            }
          : conv,
      ),
    )
  }

  const getStatusBadge = (status: string) => {
    switch (status) {
      case "active":
        return <Badge variant="default">Active</Badge>
      case "revision":
        return (
          <Badge variant="outline" className="border-yellow-500 text-yellow-700">
            Revision
          </Badge>
        )
      case "completed":
        return (
          <Badge variant="secondary" className="bg-green-100 text-green-800">
            Completed
          </Badge>
        )
      default:
        return <Badge variant="outline">{status}</Badge>
    }
  }

  const filteredConversations = conversations.filter(
    (conv) =>
      conv.orderTitle.toLowerCase().includes(searchQuery.toLowerCase()) ||
      conv.client.name.toLowerCase().includes(searchQuery.toLowerCase()),
  )

  if (isLoading) {
    return (
      <div className="min-h-screen bg-gray-50 flex items-center justify-center">
        <div className="text-center">
          <div className="animate-spin rounded-full h-12 w-12 border-b-2 border-primary mx-auto mb-4"></div>
          <p>Loading messages...</p>
        </div>
      </div>
    )
  }

  return (
    <div className="min-h-screen dashboard-academic">
      {/* Header */}
      <header className="dashboard-header-academic">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="flex justify-between items-center py-6">
            <div className="flex items-center">
              <div className="w-10 h-10 bg-primary rounded-xl flex items-center justify-center">
                <PenTool className="h-6 w-6 text-white" />
              </div>
              <span className="ml-3 text-xl font-bold text-gray-900">ProEssayWorks Writer</span>
            </div>
            <div className="flex items-center space-x-4">
              <Button variant="outline" onClick={() => router.push("/writer/dashboard")}>
                <ArrowLeft className="h-4 w-4 mr-2" />
                Back to Dashboard
              </Button>
            </div>
          </div>
        </div>
      </header>

      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-8">
        <div className="mb-8">
          <h1 className="heading-academic-secondary text-gray-900 mb-3">Messages</h1>
          <p className="body-academic-large text-gray-600">Communicate with your clients</p>
        </div>

        <div className="grid grid-cols-1 lg:grid-cols-3 gap-6 h-[calc(100vh-300px)]">
          {/* Conversations List */}
          <Card className="dashboard-card-academic">
            <CardHeader>
              <CardTitle className="heading-academic-tertiary">Conversations</CardTitle>
              <div className="relative">
                <Search className="absolute left-2 top-2.5 h-4 w-4 text-gray-400" />
                <Input
                  placeholder="Search conversations..."
                  className="pl-8"
                  value={searchQuery}
                  onChange={(e) => setSearchQuery(e.target.value)}
                />
              </div>
            </CardHeader>
            <CardContent className="p-0">
              <div className="space-y-1 max-h-96 overflow-y-auto">
                {filteredConversations.map((conversation) => (
                  <div
                    key={conversation.id}
                    className={`p-4 cursor-pointer hover:bg-gray-50 border-b transition-colors ${
                      selectedConversation?.id === conversation.id ? "bg-blue-50 border-l-4 border-l-blue-500" : ""
                    }`}
                    onClick={() => {
                      setSelectedConversation(conversation)
                      markAsRead(conversation.id)
                    }}
                  >
                    <div className="flex items-start space-x-3">
                      <Avatar className="h-10 w-10">
                        <AvatarImage src={conversation.client.avatar || "/placeholder.svg"} />
                        <AvatarFallback>
                          {conversation.client.name
                            .split(" ")
                            .map((n) => n[0])
                            .join("")}
                        </AvatarFallback>
                      </Avatar>
                      <div className="flex-1 min-w-0">
                        <div className="flex items-center justify-between mb-1">
                          <p className="text-sm font-medium text-gray-900 truncate">{conversation.client.name}</p>
                          <div className="flex items-center space-x-1">
                            {getStatusBadge(conversation.status)}
                            {conversation.unreadCount > 0 && (
                              <Badge variant="destructive" className="text-xs">
                                {conversation.unreadCount}
                              </Badge>
                            )}
                          </div>
                        </div>
                        <p className="text-xs text-gray-600 mb-1 truncate">{conversation.orderTitle}</p>
                        <p className="text-xs text-gray-500 truncate">{conversation.lastMessage}</p>
                        <div className="flex items-center justify-between mt-2">
                          <div className="flex items-center">
                            <Star className="h-3 w-3 text-yellow-500 mr-1" />
                            <span className="text-xs text-gray-500">{conversation.client.rating}</span>
                          </div>
                          <span className="text-xs text-gray-400">
                            {new Date(conversation.lastMessageTime).toLocaleDateString()}
                          </span>
                        </div>
                      </div>
                    </div>
                  </div>
                ))}
              </div>
            </CardContent>
          </Card>

          {/* Message Thread */}
          <div className="lg:col-span-2">
            {selectedConversation ? (
              <Card className="dashboard-card-academic h-full flex flex-col">
                <CardHeader className="border-b">
                  <div className="flex items-center justify-between">
                    <div className="flex items-center space-x-3">
                      <Avatar className="h-10 w-10">
                        <AvatarImage src={selectedConversation.client.avatar || "/placeholder.svg"} />
                        <AvatarFallback>
                          {selectedConversation.client.name
                            .split(" ")
                            .map((n: string) => n[0])
                            .join("")}
                        </AvatarFallback>
                      </Avatar>
                      <div>
                        <CardTitle className="text-lg">{selectedConversation.client.name}</CardTitle>
                        <CardDescription>{selectedConversation.orderTitle}</CardDescription>
                      </div>
                    </div>
                    <div className="flex items-center space-x-2">
                      {getStatusBadge(selectedConversation.status)}
                      <Button variant="ghost" size="sm">
                        <MoreVertical className="h-4 w-4" />
                      </Button>
                    </div>
                  </div>
                </CardHeader>

                {/* Messages */}
                <CardContent className="flex-1 overflow-y-auto p-4 space-y-4">
                  {selectedConversation.messages.map((message: any) => (
                    <div
                      key={message.id}
                      className={`flex ${message.sender === "writer" ? "justify-end" : "justify-start"}`}
                    >
                      <div
                        className={`max-w-xs lg:max-w-md px-4 py-2 rounded-lg ${
                          message.sender === "writer" ? "bg-blue-600 text-white" : "bg-gray-100 text-gray-900"
                        }`}
                      >
                        <p className="text-sm">{message.content}</p>
                        <div className="flex items-center justify-between mt-1">
                          <span
                            className={`text-xs ${message.sender === "writer" ? "text-blue-100" : "text-gray-500"}`}
                          >
                            {new Date(message.timestamp).toLocaleTimeString([], {
                              hour: "2-digit",
                              minute: "2-digit",
                            })}
                          </span>
                          {message.sender === "writer" && (
                            <CheckCircle
                              className={`h-3 w-3 ml-2 ${message.read ? "text-blue-200" : "text-blue-300"}`}
                            />
                          )}
                        </div>
                      </div>
                    </div>
                  ))}
                </CardContent>

                {/* Message Input */}
                <div className="border-t p-4">
                  <div className="flex space-x-2">
                    <Button variant="outline" size="sm">
                      <Paperclip className="h-4 w-4" />
                    </Button>
                    <Input
                      placeholder="Type your message..."
                      value={newMessage}
                      onChange={(e) => setNewMessage(e.target.value)}
                      onKeyPress={(e) => e.key === "Enter" && handleSendMessage()}
                      className="flex-1"
                    />
                    <Button onClick={handleSendMessage} disabled={!newMessage.trim()} className="btn-academic-primary">
                      <Send className="h-4 w-4" />
                    </Button>
                  </div>
                </div>
              </Card>
            ) : (
              <Card className="dashboard-card-academic h-full flex items-center justify-center">
                <div className="text-center">
                  <MessageSquare className="h-16 w-16 text-gray-300 mx-auto mb-4" />
                  <h3 className="text-lg font-semibold text-gray-900 mb-2">No conversation selected</h3>
                  <p className="text-gray-600">Choose a conversation from the list to start messaging</p>
                </div>
              </Card>
            )}
          </div>
        </div>
      </div>
    </div>
  )
}
